
# Slot: xenologous to


a homology relationship characterized by an interspecies (horizontal) transfer since the common ancestor.

URI: [biolink:xenologous_to](https://w3id.org/biolink/vocab/xenologous_to)

## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [homologous to](homologous_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
